@@ -47,7 +47,7 @@ use constant {
 };
 
 my $OURNAME = "sysv-rc-conf";
-my $VERSION = "1.3.0";
+my $VERSION = "1.4.0";
 my $called_as_chkconfig = $0 =~ /chkconfig$/;
 
 # Runlevel patterns: [ state regex, inverse video, colour, summary ]
@@ -115,6 +115,7 @@ my %opts = (
     verbose     => '',
     force       => 0,
     chkcfg_levels => '2345', # default runlevels to affect if not specified
+    chkcfg_info   => undef,
     chkcfg_list   => undef,
     chkcfg_add    => undef,
     chkcfg_del    => undef,
@@ -158,6 +159,7 @@ GetOptions("cache=s"	=> \$opts{cache_dir},
            "level=s"    => \$opts{chkcfg_levels},
            "type=s"     => \$opts{chkcfg_type},
            "list:s"     => \$opts{chkcfg_list},
+           "info=s"     => \$opts{chkcfg_info},
            "add=s"      => \$opts{chkcfg_add},
            "del=s"      => \$opts{chkcfg_del},
 	   "order=s"	=> \$opts{order},
@@ -205,13 +207,18 @@ if ($opts{classic}) {
 my $etc_rc = $opts{root} . "etc/rc";
 my $initd = $opts{root} . "etc/init.d";
 my @rls = qw/ 1 2 3 4 5 7 8 9 0 6 S /;
+my @all_lsb_rls = qw/ 1 2 3 4 5 0 6 S /;
 my @valid_rls = grep { -d "$etc_rc$_.d" } @rls;
 my $retcode = undef;
 my $first_write_attempted = 0;
 my $passive_ops_only = 0;
 my $delta = $opts{pictograms} ? "\x{0394}" : '#';
 
-my $LSB = App::SysVRcConf::LSB->new(root => $opts{root}, initd => "$initd/", ignore_errors => 1);
+my $LSB = App::SysVRcConf::LSB->new(
+    root => $opts{root},
+    initd => "$initd/",
+    ignore_errors => 1,
+);
 my $runlevel_cmd = '/sbin/runlevel';
 my $alt_init_handler = \%def_alt_init_handler;
 my $unsuitable_init = check_suitable_init();
@@ -236,8 +243,12 @@ my %runlevels_ui = %{dclone($status_data[0])};
 my %services = %{$status_data[1]};
 my $longest_service = length (max_by { length($_) } (keys %runlevels));
 
-if (defined $opts{chkcfg_list} or
-    $called_as_chkconfig and not defined $ARGV[0]) {
+if (defined $opts{chkcfg_info}) {
+    $retcode = infotext($opts{chkcfg_info});
+    $opts{ui} = 0;
+    $passive_ops_only = 1;
+} elsif (defined $opts{chkcfg_list} or
+         $called_as_chkconfig and not defined $ARGV[0]) {
     $opts{label_width} //= max_by { $_ } (
         DEFAULT_LIST_SN_LENGTH,
         $longest_service
@@ -280,6 +291,8 @@ if ($opts{ui}) {
     create_bottom_box();
     create_main_window( \%service_controls );
     $cui->set_binding( \&revert_changes, "r" );
+    $cui->set_binding( sub { $cui->leave_curses(); kill 'STOP', 0; }, "\cZ" );
+    $cui->set_binding( sub { $cui->mainloopExit(); }, "\cC" );
     first_service();
 }
 
@@ -373,6 +386,7 @@ sub chkconfig_emulation
     $opts{chkcfg_state} = $ARGV[1] if defined $ARGV[1];
     
     if ($opts{chkcfg_sn} && not $opts{chkcfg_state}) {
+        infotext($opts{chkcfg_sn}) if not $called_as_chkconfig;
         # Check to see if service is configured to run in current rl
         # exit true if it is, false if not.
         # See chkconfig(8) 
@@ -754,7 +768,7 @@ sub infobox
         -y      => 1,
         -height => 2,
         -text   => (join "\n",
-          (join ' ', (map { "$_".(rl_state($sn, $_) =~ tr/012/KS~/r) } qw( 1 2 3 4 5 0 6 S ))),
+          rl_prettystr($sn),
           ($lsb_rls eq rl_str($sn) ? "Using LSB defaults" : "Changed from LSB defaults"),
         ),
     );
@@ -800,6 +814,42 @@ sub infobox
     $buttons->draw();
 }
 
+sub infotext
+{
+    my ($sn) = @_;
+    my $rl_state = rl_str($sn);
+    my $svc = $services{$sn};
+
+    if (!defined $svc) {
+        printf("Service %s not present\n", $sn);
+        return 1;
+    }
+
+    my ($invert, $colour, $note) = interp($sn, $rl_state);
+    my $lsb = $svc->{lsb_info} // {};
+    my $lsb_states = join "", (map { $svc->{lsb_defaults}->{$_} // 2 } @all_lsb_rls)
+        if defined $svc->{lsb_defaults};
+    my $lsb_note;
+    ($_, $_, $lsb_note) = interp($sn, $lsb_states);
+    my $lsb_rls = (join " ", (map { $_.(($svc->{lsb_defaults}->{$_} // 2) =~ tr/012/KS~/r) } @all_lsb_rls))
+        . "  ($lsb_note)"
+        if defined $svc->{lsb_defaults};
+
+    my @infos = (
+        Service => $sn,
+        Summary => $lsb->{'Short-Description'},
+        Runlevels => rl_prettystr($sn) . "  ($note)",
+        LSB => $lsb_rls,
+        Description => $lsb->{Description},
+    );
+
+    while (my ($k, $v) = splice(@infos, 0, 2)) {
+        printf "%12s: %s\n", ($k, $v) if $v;
+    }
+
+    return 0;
+}
+
 sub get_pri_cache
 {
     my ($sn, $rl, $sk) = @_;
@@ -928,7 +978,7 @@ sub runlevel_status
             my %defs = ((map { $_ => 1 } @{($info{lsb_info}->{'Default-Start'} // [])}),
 	                (map { $_ => 0 } @{($info{lsb_info}->{'Default-Stop'} // [])})) if defined $info{lsb_info};
             $info{lsb_defaults} = \%defs;
-            $info{lsb_rls} = join "", (map { $info{lsb_defaults}->{$_} // 2 } qw( 1 2 3 4 5 0 6 S )) if defined $info{lsb_defaults};
+            $info{lsb_rls} = join "", (map { $info{lsb_defaults}->{$_} // 2 } @all_lsb_rls) if defined $info{lsb_defaults};
         }
 	$services{$service} = \%info;
     }
@@ -1056,6 +1106,7 @@ sub ui_message
 }
 
 sub ui_warning { ui_message("warning", @_) }
+sub ui_error { ui_message("error", @_) }
 
 #--- Misc subs ---#
 sub check_args
@@ -1112,7 +1163,7 @@ sub current_runlevel
 {
     if (-e $runlevel_cmd) {
         my $rl_out = `$runlevel_cmd`;
-        $rl_out = 1 if $rl_out =~ /unknown/;
+        return 1 if $rl_out =~ /unknown/;
         $rl_out =~ /^\S\s?([Ss\d])?$/ or
             die "Unknown return from $runlevel_cmd : $rl_out";
         return $1;
@@ -1387,7 +1438,9 @@ Quick key reference:
   n:           - go to next found service
   p:           - go to previous found service
   h:          Toggle help screen on / off
-  q:          Quit
+  q:          Back/quit
+  CTRL-Z:     Suspend
+  CTRL-C:     Quit
 
   Checkbox Layout:
     Space       Toggle service between most likely alternative states
@@ -1478,12 +1531,18 @@ sub rl_state
 
 sub rl_str {
     my $sn = shift;
-    return join "", (map { rl_state($sn, $_) } qw( 1 2 3 4 5 0 6 S ));
+    return join "", (map { rl_state($sn, $_) } @all_lsb_rls);
+}
+
+sub rl_prettystr {
+    my $sn = shift;
+    return join ' ', (map { "$_".(rl_state($sn, $_) =~ tr/012/KS~/r) } @all_lsb_rls);
 }
 
 sub interp
 {
     my ($sn, $str) = @_;
+    return (undef, undef, undef) if not defined $str;
 
     if ($alt_init_handler->{is_managed}->($sn)) {
         return (1, "blue", "$alt_init_handler->{manager}-managed");
@@ -1841,6 +1900,8 @@ B<sysv-rc-conf>  --add|--del  [ I<service> ]
 
 B<sysv-rc-conf> [ --level I<levels> ] I<service> E<lt>I<on|off|reset>E<gt>
 
+B<sysv-rc-conf> [ --level I<levels> ] [ --info ] I<service>
+
 =head1 DESCRIPTION
 
 B<sysv-rc-conf> gives an easy-to-use interface for managing
@@ -2031,6 +2092,15 @@ supported.
 
 Delete all runlevel symlinks for the named service.
 
+=item B<--info> [I<name>]
+
+In an extension to B<chkconfig>, this option will show some information about
+the service, its current configuration, and information from the LSB header
+if available.
+
+This information is also presented if the only argument on the command line
+is the service name and the tool is not invoked as B<chkconfig>.
+
 =back
 
 =head1 USING THE GUI
@@ -2113,11 +2183,17 @@ Examples:
   # sysv-rc-conf --level 35 ssh off
   # sysv-rc-conf atd on
   # sysv-rc-conf acct reset
+  # sysv-rc-conf cron || echo cron is not started
 
 The first example will turn ssh off on levels 3 and 5. The second example
 turns atd on for runlevels 2, 3, 4, and 5. The third example sets the on/off
 state for each runlevel based on the defaults specified in the LSB header.
 
+If invoked with only a service name, the return code is set to 0 if the
+service is enabled in the current (or defined-by C<--level>) runlevel. If
+not invoked as B<chkconfig> then the information displayed by C<--info> is
+also printed.
+
 =head1 FILES
 
 =over
